export default {
    set({
        commit
    }, user) {
        commit('set', {
            user: user
        })
    },
    setSSOApi({
        commit
    }, apiEndpoint) {
        commit('setSSOApi', {
            api: apiEndpoint
        })
    },
    setAccountApi({
        commit
    }, apiEndpoint) {
        commit('setAccountApi', {
            api: apiEndpoint
        })
    },
    setLogged({
        commit
    }, logged) {
        commit('setLogged', {
            logged: logged
        })
    },
    setAcceptTermsConditions({
        commit
    }, terms) {
        commit('setAcceptTermsConditions', {
            terms: terms
        })
    },
    setOptOutMarketing({
        commit
    }, opt_in) {
        commit('setOptOutMarketing', {
            opt_in: opt_in
        })
    },
    setChecked({
        commit
    }, val) {
        commit('setChecked', {
            val: val
        })
    },
    setBearer({
        commit
    }, bearer) {
        commit('setBearer', {
            bearer: bearer
        })
    },
    login({
        state,
        commit
    }, object) {
        return new Promise((resolve, reject) => {
            object.remember = true;
            axios.post(state.sso_api + "ajax-login", object, {
                withCredentials: true
            }).then(r => {
                resolve(r);
            }).catch(e => {
                reject(e);
            })
        });
    },
    autoLogin({
        state,
        commit
    }, object) {
        return new Promise((resolve, reject) => {
            //SSo api has last /
            axios.post(state.sso_api + "oauth/personal-access-tokens", {
                    name: "Digitaltown",
                    scopes: ['ID', 'email', 'profile', 'business', 'avatar'],
                }, {
                    withCredentials: true
                })
                .then((response) => {
                    let accessToken = response.data.accessToken;
                    object.setBearer(accessToken);
                    commit('setBearer', {
                        bearer: accessToken
                    })
                    if (accessToken) {
                        axios.get(state.sso_api + "api/v1/user", {
                                headers: {
                                    "Authorization": "Bearer " + accessToken
                                },
                            }).then((response) => {
                                if (response.status == 200) {
                                    commit("setSSOInfo", {
                                        data: response.data
                                    });
                                    resolve(response.data);
                                } else {
                                    Vue.set(state, 'logged', false);
                                    reject(response.data);
                                }
                            })
                            .catch((e) => {
                                console.log(e, " there was an error while creating the sessionID in account");
                                Vue.set(state, 'logged', false);
                                reject(e);
                            })
                    } else {
                        reject(response.data);
                    }
                }).catch((e) => {
                    commit("setLogged", {
                        logged: false
                    });
                    reject(e);
                })
        });
    },

    setProfile({
        state,
        commit
    }, object) {
        return new Promise((resolve, reject) => {
            //Calls ACCOUNT profile
            axios.post("/api/v1/profile/load", {
                    uuid: state.profile.uuid,
                }, state.config)
                .then((r) => {
                    if (r.data.ok == false) {
                        reject(r);
                    } else {
                        commit("setProfileInfo", {
                            data: r.data
                        });
                        resolve(r);
                    }
                }).catch((e) => {
                    reject(e);
                })
        });
    },

    setReferredUsers({
        state,
        commit
    }, hash) {
        return new Promise((resolve, reject) => {
            if (state.logged == true) {
                axios.get('/api/profile/referrals', {
                        params: {
                            hash: state.profile.hash
                        }
                    })
                    .then(function(response) {
                        commit('setReferredUsers', response.data)
                        resolve(response);
                    }.bind(this))
                    .catch(function(error) {
                        reject(error);
                    }.bind(this));
            } else {
                commit('setReferredUsers', []);
            }
        });
    },

    isPrivateMode({
        state,
    }) {
        return new Promise((resolve) => {
            const on = () => resolve(true); // is in private mode
            const off = () => resolve(false); // not private mode
            const testLocalStorage = () => {
                try {
                    return window.openDatabase(null, null, null, null) ? off() : on();
                } catch (e) {
                    return on();
                }
            };
            // Chrome & Opera
            if (window.webkitRequestFileSystem) {
                return void window.webkitRequestFileSystem(0, 0, off, on);
            }
            // Firefox
            if ('MozAppearance' in document.documentElement.style) {
                const db = indexedDB.open('test');
                db.onerror = on;
                db.onsuccess = off;
                return void 0;
            }
            // Safari
            var ua = navigator.userAgent.toLowerCase();
            if (ua.indexOf('safari') > -1) {
                return testLocalStorage();
            }
            // IE10+ & Edge
            if (!window.indexedDB && (window.PointerEvent || window.MSPointerEvent)) {
                return on();
            }
            // others
            return off();
        });
    },

    setAppUser({
        commit
    }, app_user) {
        commit('storeAppUser', {
            app_user: app_user
        })
    },

    getUserWallets({
        commit,
        state,
        rootState,
    }) {
        return new Promise((resolve, reject) => {
            if (state.logged == true) {
                axios.get(rootState.site.ecosystem['wallet-api'].base_url + "/api/v1/wallets", {
                        headers: {
                            "Authorization": "Bearer " + state.bearer
                        },
                    })
                    .then(function(response) {
                        commit('setWallets', response.data.result[0].data)
                        resolve(response);
                    }.bind(this))
                    .catch(function(error) {
                        reject(error);
                    }.bind(this));
            }
        });

    }
}
